# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `MetadataStore.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice_BuiltinSequences_ice
import omero_ModelF_ice
import omero_ServicesF_ice
import omero_Scripts_ice
import omero_Repositories_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Included module omero.grid
_M_omero.grid = Ice.openModule('omero.grid')

# Included module omero.cmd
_M_omero.cmd = Ice.openModule('omero.cmd')

# Start of module omero
__name__ = 'omero'

# Start of module omero.constants
_M_omero.constants = Ice.openModule('omero.constants')
__name__ = 'omero.constants'

_M_omero.constants.METADATASTORE = "omero.api.MetadataStore"

# End of module omero.constants

__name__ = 'omero'

# Start of module omero.metadatastore
_M_omero.metadatastore = Ice.openModule('omero.metadatastore')
__name__ = 'omero.metadatastore'
_M_omero.metadatastore.__doc__ = """
Types used during import.
"""

if 'IObjectContainer' not in _M_omero.metadatastore.__dict__:
    _M_omero.metadatastore.IObjectContainer = Ice.createTempClass()
    class IObjectContainer(Ice.Object):
        """
        Container-class used by the import mechanism. Passed to
        omero.api.MetadataStore
        """
        def __init__(self, LSID='', indexes=None, sourceObject=None):
            self.LSID = LSID
            self.indexes = indexes
            self.sourceObject = sourceObject

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::metadatastore::IObjectContainer')

        def ice_id(self, current=None):
            return '::omero::metadatastore::IObjectContainer'

        def ice_staticId():
            return '::omero::metadatastore::IObjectContainer'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.metadatastore._t_IObjectContainer)

        __repr__ = __str__

    _M_omero.metadatastore.IObjectContainerPrx = Ice.createTempClass()
    class IObjectContainerPrx(Ice.ObjectPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.metadatastore.IObjectContainerPrx.ice_checkedCast(proxy, '::omero::metadatastore::IObjectContainer', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.metadatastore.IObjectContainerPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::metadatastore::IObjectContainer'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.metadatastore._t_IObjectContainerPrx = IcePy.defineProxy('::omero::metadatastore::IObjectContainer', IObjectContainerPrx)

    _M_omero.metadatastore._t_IObjectContainer = IcePy.declareClass('::omero::metadatastore::IObjectContainer')

    _M_omero.metadatastore._t_IObjectContainer = IcePy.defineClass('::omero::metadatastore::IObjectContainer', IObjectContainer, -1, (), False, False, None, (), (
        ('LSID', (), IcePy._t_string, False, 0),
        ('indexes', (), _M_omero.api._t_StringIntMap, False, 0),
        ('sourceObject', (), _M_omero.model._t_IObject, False, 0)
    ))
    IObjectContainer._ice_type = _M_omero.metadatastore._t_IObjectContainer

    _M_omero.metadatastore.IObjectContainer = IObjectContainer
    del IObjectContainer

    _M_omero.metadatastore.IObjectContainerPrx = IObjectContainerPrx
    del IObjectContainerPrx

if '_t_IObjectContainerArray' not in _M_omero.metadatastore.__dict__:
    _M_omero.metadatastore._t_IObjectContainerArray = IcePy.defineSequence('::omero::metadatastore::IObjectContainerArray', (), _M_omero.metadatastore._t_IObjectContainer)

# End of module omero.metadatastore

__name__ = 'omero'

# Start of module omero.api
__name__ = 'omero.api'

if 'MetadataStore' not in _M_omero.api.__dict__:
    _M_omero.api.MetadataStore = Ice.createTempClass()
    class MetadataStore(_M_omero.api.StatefulServiceInterface):
        """
        Server-side interface for import.
        """
        def __init__(self):
            if Ice.getType(self) == _M_omero.api.MetadataStore:
                raise RuntimeError('omero.api.MetadataStore is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::api::MetadataStore', '::omero::api::ServiceInterface', '::omero::api::StatefulServiceInterface')

        def ice_id(self, current=None):
            return '::omero::api::MetadataStore'

        def ice_staticId():
            return '::omero::api::MetadataStore'
        ice_staticId = staticmethod(ice_staticId)

        def createRoot_async(self, _cb, current=None):
            pass

        def updateObjects_async(self, _cb, objects, current=None):
            pass

        def updateReferences_async(self, _cb, references, current=None):
            pass

        def saveToDB_async(self, _cb, activity, current=None):
            pass

        def populateMinMax_async(self, _cb, imageChannelGlobalMinMax, current=None):
            pass

        def setPixelsFile_async(self, _cb, pixelsId, file, repo, current=None):
            pass

        def postProcess_async(self, _cb, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.api._t_MetadataStore)

        __repr__ = __str__

    _M_omero.api.MetadataStorePrx = Ice.createTempClass()
    class MetadataStorePrx(_M_omero.api.StatefulServiceInterfacePrx):

        def createRoot(self, _ctx=None):
            return _M_omero.api.MetadataStore._op_createRoot.invoke(self, ((), _ctx))

        def begin_createRoot(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.MetadataStore._op_createRoot.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_createRoot(self, _r):
            return _M_omero.api.MetadataStore._op_createRoot.end(self, _r)

        def updateObjects(self, objects, _ctx=None):
            return _M_omero.api.MetadataStore._op_updateObjects.invoke(self, ((objects, ), _ctx))

        def begin_updateObjects(self, objects, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.MetadataStore._op_updateObjects.begin(self, ((objects, ), _response, _ex, _sent, _ctx))

        def end_updateObjects(self, _r):
            return _M_omero.api.MetadataStore._op_updateObjects.end(self, _r)

        def updateReferences(self, references, _ctx=None):
            return _M_omero.api.MetadataStore._op_updateReferences.invoke(self, ((references, ), _ctx))

        def begin_updateReferences(self, references, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.MetadataStore._op_updateReferences.begin(self, ((references, ), _response, _ex, _sent, _ctx))

        def end_updateReferences(self, _r):
            return _M_omero.api.MetadataStore._op_updateReferences.end(self, _r)

        def saveToDB(self, activity, _ctx=None):
            return _M_omero.api.MetadataStore._op_saveToDB.invoke(self, ((activity, ), _ctx))

        def begin_saveToDB(self, activity, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.MetadataStore._op_saveToDB.begin(self, ((activity, ), _response, _ex, _sent, _ctx))

        def end_saveToDB(self, _r):
            return _M_omero.api.MetadataStore._op_saveToDB.end(self, _r)

        def populateMinMax(self, imageChannelGlobalMinMax, _ctx=None):
            return _M_omero.api.MetadataStore._op_populateMinMax.invoke(self, ((imageChannelGlobalMinMax, ), _ctx))

        def begin_populateMinMax(self, imageChannelGlobalMinMax, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.MetadataStore._op_populateMinMax.begin(self, ((imageChannelGlobalMinMax, ), _response, _ex, _sent, _ctx))

        def end_populateMinMax(self, _r):
            return _M_omero.api.MetadataStore._op_populateMinMax.end(self, _r)

        def setPixelsFile(self, pixelsId, file, repo, _ctx=None):
            return _M_omero.api.MetadataStore._op_setPixelsFile.invoke(self, ((pixelsId, file, repo), _ctx))

        def begin_setPixelsFile(self, pixelsId, file, repo, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.MetadataStore._op_setPixelsFile.begin(self, ((pixelsId, file, repo), _response, _ex, _sent, _ctx))

        def end_setPixelsFile(self, _r):
            return _M_omero.api.MetadataStore._op_setPixelsFile.end(self, _r)

        def postProcess(self, _ctx=None):
            return _M_omero.api.MetadataStore._op_postProcess.invoke(self, ((), _ctx))

        def begin_postProcess(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.MetadataStore._op_postProcess.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_postProcess(self, _r):
            return _M_omero.api.MetadataStore._op_postProcess.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.api.MetadataStorePrx.ice_checkedCast(proxy, '::omero::api::MetadataStore', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.api.MetadataStorePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::api::MetadataStore'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.api._t_MetadataStorePrx = IcePy.defineProxy('::omero::api::MetadataStore', MetadataStorePrx)

    _M_omero.api._t_MetadataStore = IcePy.defineClass('::omero::api::MetadataStore', MetadataStore, -1, (), True, False, None, (_M_omero.api._t_StatefulServiceInterface,), ())
    MetadataStore._ice_type = _M_omero.api._t_MetadataStore

    MetadataStore._op_createRoot = IcePy.Operation('createRoot', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (), (), None, (_M_omero._t_ServerError,))
    MetadataStore._op_updateObjects = IcePy.Operation('updateObjects', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.metadatastore._t_IObjectContainerArray, False, 0),), (), None, (_M_omero._t_ServerError,))
    MetadataStore._op_updateReferences = IcePy.Operation('updateReferences', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.api._t_StringStringArrayMap, False, 0),), (), None, (_M_omero._t_ServerError,))
    MetadataStore._op_saveToDB = IcePy.Operation('saveToDB', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.model._t_FilesetJobLink, False, 0),), (), ((), _M_omero.api._t_IObjectListMap, False, 0), (_M_omero._t_ServerError,))
    MetadataStore._op_populateMinMax = IcePy.Operation('populateMinMax', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.api._t_DoubleArrayArrayArray, False, 0),), (), None, (_M_omero._t_ServerError,))
    MetadataStore._op_setPixelsFile = IcePy.Operation('setPixelsFile', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_long, False, 0), ((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0)), (), None, (_M_omero._t_ServerError,))
    MetadataStore._op_postProcess = IcePy.Operation('postProcess', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (), (), ((), _M_omero.grid._t_InteractiveProcessorList, False, 0), (_M_omero._t_ServerError,))

    _M_omero.api.MetadataStore = MetadataStore
    del MetadataStore

    _M_omero.api.MetadataStorePrx = MetadataStorePrx
    del MetadataStorePrx

# End of module omero.api

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `IUpdate.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_cmd_API_ice
import omero_ServicesF_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Included module omero.cmd
_M_omero.cmd = Ice.openModule('omero.cmd')

# Included module omero.grid
_M_omero.grid = Ice.openModule('omero.grid')

# Start of module omero
__name__ = 'omero'

# Start of module omero.api
__name__ = 'omero.api'

if 'IUpdate' not in _M_omero.api.__dict__:
    _M_omero.api.IUpdate = Ice.createTempClass()
    class IUpdate(_M_omero.api.ServiceInterface):
        """
        Provides methods for directly updating object graphs. IUpdate is
        the lowest level (level-1) interface which may make changes
        (INSERT, UPDATE, DELETE) to the database. All other methods of
        changing the database may leave it in an inconsistent state.
        All the save* methods act recursively on the entire object graph,
        replacing placeholders and details where necessary, and then
        merging the final graph.
        This means that the objects that are passed into IUpdate.save*
        methods are copied over to new instances which are then returned.
        The original objects should be discarded.
        {@code saveAndReturnIds} behaves slightly differently in that
        it does not handle object modifications. The graph of
        objects passed in can consist ONLY if either newly created
        objects without ids or of unloaded objects with ids. Note:
        The ids of the saved values may not be in order. This is caused by
        persistence-by-transitivity. Hibernate may detect an item later in
        the array if they are interconnected and therefore choose to save
        it first.
        All methods throw omero.ValidationException if the input
        objects do not pass validation, and
        omero.OptimisticLockException if the version of a given has
        already been incremented.
        """
        def __init__(self):
            if Ice.getType(self) == _M_omero.api.IUpdate:
                raise RuntimeError('omero.api.IUpdate is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::api::IUpdate', '::omero::api::ServiceInterface')

        def ice_id(self, current=None):
            return '::omero::api::IUpdate'

        def ice_staticId():
            return '::omero::api::IUpdate'
        ice_staticId = staticmethod(ice_staticId)

        def saveObject_async(self, _cb, obj, current=None):
            pass

        def saveCollection_async(self, _cb, objs, current=None):
            pass

        def saveAndReturnObject_async(self, _cb, obj, current=None):
            pass

        def saveArray_async(self, _cb, graph, current=None):
            pass

        def saveAndReturnArray_async(self, _cb, graph, current=None):
            pass

        def saveAndReturnIds_async(self, _cb, graph, current=None):
            pass

        def deleteObject_async(self, _cb, row, current=None):
            pass

        def indexObject_async(self, _cb, row, current=None):
            """
            Initiates full-text indexing for the given object. This may
            have to wait
            for the current {@code FullTextThread} to finish.
            Can only be executed by an admin. Other users must wait for
            the background Thread to complete.
            Arguments:
            _cb -- The asynchronous callback object.
            row -- a persistent omero.model.IObject to be deleted
            current -- The Current object for the invocation.
            Throws:
            ValidationException -- if the object does not exist or is nul
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.api._t_IUpdate)

        __repr__ = __str__

    _M_omero.api.IUpdatePrx = Ice.createTempClass()
    class IUpdatePrx(_M_omero.api.ServiceInterfacePrx):

        def saveObject(self, obj, _ctx=None):
            return _M_omero.api.IUpdate._op_saveObject.invoke(self, ((obj, ), _ctx))

        def begin_saveObject(self, obj, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IUpdate._op_saveObject.begin(self, ((obj, ), _response, _ex, _sent, _ctx))

        def end_saveObject(self, _r):
            return _M_omero.api.IUpdate._op_saveObject.end(self, _r)

        def saveCollection(self, objs, _ctx=None):
            return _M_omero.api.IUpdate._op_saveCollection.invoke(self, ((objs, ), _ctx))

        def begin_saveCollection(self, objs, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IUpdate._op_saveCollection.begin(self, ((objs, ), _response, _ex, _sent, _ctx))

        def end_saveCollection(self, _r):
            return _M_omero.api.IUpdate._op_saveCollection.end(self, _r)

        def saveAndReturnObject(self, obj, _ctx=None):
            return _M_omero.api.IUpdate._op_saveAndReturnObject.invoke(self, ((obj, ), _ctx))

        def begin_saveAndReturnObject(self, obj, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IUpdate._op_saveAndReturnObject.begin(self, ((obj, ), _response, _ex, _sent, _ctx))

        def end_saveAndReturnObject(self, _r):
            return _M_omero.api.IUpdate._op_saveAndReturnObject.end(self, _r)

        def saveArray(self, graph, _ctx=None):
            return _M_omero.api.IUpdate._op_saveArray.invoke(self, ((graph, ), _ctx))

        def begin_saveArray(self, graph, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IUpdate._op_saveArray.begin(self, ((graph, ), _response, _ex, _sent, _ctx))

        def end_saveArray(self, _r):
            return _M_omero.api.IUpdate._op_saveArray.end(self, _r)

        def saveAndReturnArray(self, graph, _ctx=None):
            return _M_omero.api.IUpdate._op_saveAndReturnArray.invoke(self, ((graph, ), _ctx))

        def begin_saveAndReturnArray(self, graph, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IUpdate._op_saveAndReturnArray.begin(self, ((graph, ), _response, _ex, _sent, _ctx))

        def end_saveAndReturnArray(self, _r):
            return _M_omero.api.IUpdate._op_saveAndReturnArray.end(self, _r)

        def saveAndReturnIds(self, graph, _ctx=None):
            return _M_omero.api.IUpdate._op_saveAndReturnIds.invoke(self, ((graph, ), _ctx))

        def begin_saveAndReturnIds(self, graph, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IUpdate._op_saveAndReturnIds.begin(self, ((graph, ), _response, _ex, _sent, _ctx))

        def end_saveAndReturnIds(self, _r):
            return _M_omero.api.IUpdate._op_saveAndReturnIds.end(self, _r)

        def deleteObject(self, row, _ctx=None):
            return _M_omero.api.IUpdate._op_deleteObject.invoke(self, ((row, ), _ctx))

        def begin_deleteObject(self, row, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IUpdate._op_deleteObject.begin(self, ((row, ), _response, _ex, _sent, _ctx))

        def end_deleteObject(self, _r):
            return _M_omero.api.IUpdate._op_deleteObject.end(self, _r)

        """
        Initiates full-text indexing for the given object. This may
        have to wait
        for the current {@code FullTextThread} to finish.
        Can only be executed by an admin. Other users must wait for
        the background Thread to complete.
        Arguments:
        row -- a persistent omero.model.IObject to be deleted
        _ctx -- The request context for the invocation.
        Throws:
        ValidationException -- if the object does not exist or is nul
        """
        def indexObject(self, row, _ctx=None):
            return _M_omero.api.IUpdate._op_indexObject.invoke(self, ((row, ), _ctx))

        """
        Initiates full-text indexing for the given object. This may
        have to wait
        for the current {@code FullTextThread} to finish.
        Can only be executed by an admin. Other users must wait for
        the background Thread to complete.
        Arguments:
        row -- a persistent omero.model.IObject to be deleted
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_indexObject(self, row, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.IUpdate._op_indexObject.begin(self, ((row, ), _response, _ex, _sent, _ctx))

        """
        Initiates full-text indexing for the given object. This may
        have to wait
        for the current {@code FullTextThread} to finish.
        Can only be executed by an admin. Other users must wait for
        the background Thread to complete.
        Arguments:
        row -- a persistent omero.model.IObject to be deleted
        Throws:
        ValidationException -- if the object does not exist or is nul
        """
        def end_indexObject(self, _r):
            return _M_omero.api.IUpdate._op_indexObject.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.api.IUpdatePrx.ice_checkedCast(proxy, '::omero::api::IUpdate', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.api.IUpdatePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::api::IUpdate'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.api._t_IUpdatePrx = IcePy.defineProxy('::omero::api::IUpdate', IUpdatePrx)

    _M_omero.api._t_IUpdate = IcePy.defineClass('::omero::api::IUpdate', IUpdate, -1, (), True, False, None, (_M_omero.api._t_ServiceInterface,), ())
    IUpdate._ice_type = _M_omero.api._t_IUpdate

    IUpdate._op_saveObject = IcePy.Operation('saveObject', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.model._t_IObject, False, 0),), (), None, (_M_omero._t_ServerError,))
    IUpdate._op_saveCollection = IcePy.Operation('saveCollection', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.api._t_IObjectList, False, 0),), (), None, (_M_omero._t_ServerError,))
    IUpdate._op_saveAndReturnObject = IcePy.Operation('saveAndReturnObject', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.model._t_IObject, False, 0),), (), ((), _M_omero.model._t_IObject, False, 0), (_M_omero._t_ServerError,))
    IUpdate._op_saveArray = IcePy.Operation('saveArray', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.api._t_IObjectList, False, 0),), (), None, (_M_omero._t_ServerError,))
    IUpdate._op_saveAndReturnArray = IcePy.Operation('saveAndReturnArray', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.api._t_IObjectList, False, 0),), (), ((), _M_omero.api._t_IObjectList, False, 0), (_M_omero._t_ServerError,))
    IUpdate._op_saveAndReturnIds = IcePy.Operation('saveAndReturnIds', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.api._t_IObjectList, False, 0),), (), ((), _M_omero.sys._t_LongList, False, 0), (_M_omero._t_ServerError,))
    IUpdate._op_deleteObject = IcePy.Operation('deleteObject', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (((), _M_omero.model._t_IObject, False, 0),), (), None, (_M_omero._t_ServerError,))
    IUpdate._op_deleteObject.deprecate("use omero::cmd::Delete2 instead")
    IUpdate._op_indexObject = IcePy.Operation('indexObject', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), _M_omero.model._t_IObject, False, 0),), (), None, (_M_omero._t_ServerError,))

    _M_omero.api.IUpdate = IUpdate
    del IUpdate

    _M_omero.api.IUpdatePrx = IUpdatePrx
    del IUpdatePrx

if 'Save' not in _M_omero.api.__dict__:
    _M_omero.api.Save = Ice.createTempClass()
    class Save(_M_omero.cmd.Request):
        def __init__(self, obj=None):
            _M_omero.cmd.Request.__init__(self)
            self.obj = obj

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::api::Save', '::omero::cmd::Request')

        def ice_id(self, current=None):
            return '::omero::api::Save'

        def ice_staticId():
            return '::omero::api::Save'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.api._t_Save)

        __repr__ = __str__

    _M_omero.api.SavePrx = Ice.createTempClass()
    class SavePrx(_M_omero.cmd.RequestPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.api.SavePrx.ice_checkedCast(proxy, '::omero::api::Save', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.api.SavePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::api::Save'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.api._t_SavePrx = IcePy.defineProxy('::omero::api::Save', SavePrx)

    _M_omero.api._t_Save = IcePy.declareClass('::omero::api::Save')

    _M_omero.api._t_Save = IcePy.defineClass('::omero::api::Save', Save, -1, (), False, False, _M_omero.cmd._t_Request, (), (('obj', (), _M_omero.model._t_IObject, False, 0),))
    Save._ice_type = _M_omero.api._t_Save

    _M_omero.api.Save = Save
    del Save

    _M_omero.api.SavePrx = SavePrx
    del SavePrx

if 'SaveRsp' not in _M_omero.api.__dict__:
    _M_omero.api.SaveRsp = Ice.createTempClass()
    class SaveRsp(_M_omero.cmd.Response):
        def __init__(self, obj=None):
            _M_omero.cmd.Response.__init__(self)
            self.obj = obj

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::api::SaveRsp', '::omero::cmd::Response')

        def ice_id(self, current=None):
            return '::omero::api::SaveRsp'

        def ice_staticId():
            return '::omero::api::SaveRsp'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.api._t_SaveRsp)

        __repr__ = __str__

    _M_omero.api.SaveRspPrx = Ice.createTempClass()
    class SaveRspPrx(_M_omero.cmd.ResponsePrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.api.SaveRspPrx.ice_checkedCast(proxy, '::omero::api::SaveRsp', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.api.SaveRspPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::api::SaveRsp'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.api._t_SaveRspPrx = IcePy.defineProxy('::omero::api::SaveRsp', SaveRspPrx)

    _M_omero.api._t_SaveRsp = IcePy.declareClass('::omero::api::SaveRsp')

    _M_omero.api._t_SaveRsp = IcePy.defineClass('::omero::api::SaveRsp', SaveRsp, -1, (), False, False, _M_omero.cmd._t_Response, (), (('obj', (), _M_omero.model._t_IObject, False, 0),))
    SaveRsp._ice_type = _M_omero.api._t_SaveRsp

    _M_omero.api.SaveRsp = SaveRsp
    del SaveRsp

    _M_omero.api.SaveRspPrx = SaveRspPrx
    del SaveRspPrx

# End of module omero.api

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright 2016 University of Dundee. All rights reserved.
# Use is subject to license terms supplied in LICENSE.txt

"""
Python helper plugin 
"""

import sys
import platform
import warnings

warnings.warn(
    "This module is deprecated as of OMERO.py 5.6.0", DeprecationWarning)

PYTHON_WARNING = ("Python version %s is not "
                  "supported!" % platform.python_version())


def py27_only():
    if sys.version_info < (2, 7) or sys.version_info >= (2, 8):
        return False
    return True



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Details.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_ModelF_ice
import omero_System_ice
import Ice_Current_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model.Details = Ice.createTempClass()
    class Details(Ice.Object):
        """
        Embedded component of every OMERO.blitz type. Since this is
        not an IObject subclass, no attempt is made to hide the state
        of this object, since it cannot be ""unloaded"".
        Members:
        owner -- 
        group -- 
        creationEvent -- 
        updateEvent -- 
        permissions -- 
        externalInfo -- 
        call -- Context which was active during the call which
        returned this object. This context is set as
        the last (optional) argument of any remote
        Ice invocation. This is used to change the
        user, group, share, etc. of the current session.
        event -- Context which would have been returned by a
        simultaneous call to {@code omero.api.IAdmin.getEventContext}
        while this object was being loaded.
        """
        def __init__(self, _owner=None, _group=None, _creationEvent=None, _updateEvent=None, _permissions=None, _externalInfo=None, _call=None, _event=None):
            if Ice.getType(self) == _M_omero.model.Details:
                raise RuntimeError('omero.model.Details is an abstract class')
            self._owner = _owner
            self._group = _group
            self._creationEvent = _creationEvent
            self._updateEvent = _updateEvent
            self._permissions = _permissions
            self._externalInfo = _externalInfo
            self._call = _call
            self._event = _event

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::Details')

        def ice_id(self, current=None):
            return '::omero::model::Details'

        def ice_staticId():
            return '::omero::model::Details'
        ice_staticId = staticmethod(ice_staticId)

        def getOwner(self, current=None):
            pass

        def setOwner(self, theOwner, current=None):
            pass

        def getGroup(self, current=None):
            pass

        def setGroup(self, theGroup, current=None):
            pass

        def getCreationEvent(self, current=None):
            pass

        def setCreationEvent(self, theCreationEvent, current=None):
            pass

        def getUpdateEvent(self, current=None):
            pass

        def setUpdateEvent(self, theUpdateEvent, current=None):
            pass

        def getPermissions(self, current=None):
            pass

        def setPermissions(self, thePermissions, current=None):
            pass

        def getExternalInfo(self, current=None):
            pass

        def setExternalInfo(self, theExternalInfo, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Details)

        __repr__ = __str__

    _M_omero.model.DetailsPrx = Ice.createTempClass()
    class DetailsPrx(Ice.ObjectPrx):

        def getOwner(self, _ctx=None):
            return _M_omero.model.Details._op_getOwner.invoke(self, ((), _ctx))

        def begin_getOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Details._op_getOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getOwner(self, _r):
            return _M_omero.model.Details._op_getOwner.end(self, _r)

        def setOwner(self, theOwner, _ctx=None):
            return _M_omero.model.Details._op_setOwner.invoke(self, ((theOwner, ), _ctx))

        def begin_setOwner(self, theOwner, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Details._op_setOwner.begin(self, ((theOwner, ), _response, _ex, _sent, _ctx))

        def end_setOwner(self, _r):
            return _M_omero.model.Details._op_setOwner.end(self, _r)

        def getGroup(self, _ctx=None):
            return _M_omero.model.Details._op_getGroup.invoke(self, ((), _ctx))

        def begin_getGroup(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Details._op_getGroup.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getGroup(self, _r):
            return _M_omero.model.Details._op_getGroup.end(self, _r)

        def setGroup(self, theGroup, _ctx=None):
            return _M_omero.model.Details._op_setGroup.invoke(self, ((theGroup, ), _ctx))

        def begin_setGroup(self, theGroup, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Details._op_setGroup.begin(self, ((theGroup, ), _response, _ex, _sent, _ctx))

        def end_setGroup(self, _r):
            return _M_omero.model.Details._op_setGroup.end(self, _r)

        def getCreationEvent(self, _ctx=None):
            return _M_omero.model.Details._op_getCreationEvent.invoke(self, ((), _ctx))

        def begin_getCreationEvent(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Details._op_getCreationEvent.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getCreationEvent(self, _r):
            return _M_omero.model.Details._op_getCreationEvent.end(self, _r)

        def setCreationEvent(self, theCreationEvent, _ctx=None):
            return _M_omero.model.Details._op_setCreationEvent.invoke(self, ((theCreationEvent, ), _ctx))

        def begin_setCreationEvent(self, theCreationEvent, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Details._op_setCreationEvent.begin(self, ((theCreationEvent, ), _response, _ex, _sent, _ctx))

        def end_setCreationEvent(self, _r):
            return _M_omero.model.Details._op_setCreationEvent.end(self, _r)

        def getUpdateEvent(self, _ctx=None):
            return _M_omero.model.Details._op_getUpdateEvent.invoke(self, ((), _ctx))

        def begin_getUpdateEvent(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Details._op_getUpdateEvent.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getUpdateEvent(self, _r):
            return _M_omero.model.Details._op_getUpdateEvent.end(self, _r)

        def setUpdateEvent(self, theUpdateEvent, _ctx=None):
            return _M_omero.model.Details._op_setUpdateEvent.invoke(self, ((theUpdateEvent, ), _ctx))

        def begin_setUpdateEvent(self, theUpdateEvent, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Details._op_setUpdateEvent.begin(self, ((theUpdateEvent, ), _response, _ex, _sent, _ctx))

        def end_setUpdateEvent(self, _r):
            return _M_omero.model.Details._op_setUpdateEvent.end(self, _r)

        def getPermissions(self, _ctx=None):
            return _M_omero.model.Details._op_getPermissions.invoke(self, ((), _ctx))

        def begin_getPermissions(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Details._op_getPermissions.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPermissions(self, _r):
            return _M_omero.model.Details._op_getPermissions.end(self, _r)

        def setPermissions(self, thePermissions, _ctx=None):
            return _M_omero.model.Details._op_setPermissions.invoke(self, ((thePermissions, ), _ctx))

        def begin_setPermissions(self, thePermissions, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Details._op_setPermissions.begin(self, ((thePermissions, ), _response, _ex, _sent, _ctx))

        def end_setPermissions(self, _r):
            return _M_omero.model.Details._op_setPermissions.end(self, _r)

        def getExternalInfo(self, _ctx=None):
            return _M_omero.model.Details._op_getExternalInfo.invoke(self, ((), _ctx))

        def begin_getExternalInfo(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Details._op_getExternalInfo.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getExternalInfo(self, _r):
            return _M_omero.model.Details._op_getExternalInfo.end(self, _r)

        def setExternalInfo(self, theExternalInfo, _ctx=None):
            return _M_omero.model.Details._op_setExternalInfo.invoke(self, ((theExternalInfo, ), _ctx))

        def begin_setExternalInfo(self, theExternalInfo, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Details._op_setExternalInfo.begin(self, ((theExternalInfo, ), _response, _ex, _sent, _ctx))

        def end_setExternalInfo(self, _r):
            return _M_omero.model.Details._op_setExternalInfo.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.DetailsPrx.ice_checkedCast(proxy, '::omero::model::Details', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.DetailsPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Details'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_DetailsPrx = IcePy.defineProxy('::omero::model::Details', DetailsPrx)

    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')

    _M_omero.model._t_Details = IcePy.defineClass('::omero::model::Details', Details, -1, (), True, False, None, (), (
        ('_owner', (), _M_omero.model._t_Experimenter, False, 0),
        ('_group', (), _M_omero.model._t_ExperimenterGroup, False, 0),
        ('_creationEvent', (), _M_omero.model._t_Event, False, 0),
        ('_updateEvent', (), _M_omero.model._t_Event, False, 0),
        ('_permissions', (), _M_omero.model._t_Permissions, False, 0),
        ('_externalInfo', (), _M_omero.model._t_ExternalInfo, False, 0),
        ('_call', (), _M_Ice._t_Context, False, 0),
        ('_event', (), _M_omero.sys._t_EventContext, False, 0)
    ))
    Details._ice_type = _M_omero.model._t_Details

    Details._op_getOwner = IcePy.Operation('getOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Experimenter, False, 0), ())
    Details._op_setOwner = IcePy.Operation('setOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Experimenter, False, 0),), (), None, ())
    Details._op_getGroup = IcePy.Operation('getGroup', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ExperimenterGroup, False, 0), ())
    Details._op_setGroup = IcePy.Operation('setGroup', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimenterGroup, False, 0),), (), None, ())
    Details._op_getCreationEvent = IcePy.Operation('getCreationEvent', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Event, False, 0), ())
    Details._op_setCreationEvent = IcePy.Operation('setCreationEvent', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Event, False, 0),), (), None, ())
    Details._op_getUpdateEvent = IcePy.Operation('getUpdateEvent', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Event, False, 0), ())
    Details._op_setUpdateEvent = IcePy.Operation('setUpdateEvent', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Event, False, 0),), (), None, ())
    Details._op_getPermissions = IcePy.Operation('getPermissions', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Permissions, False, 0), ())
    Details._op_setPermissions = IcePy.Operation('setPermissions', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Permissions, False, 0),), (), None, ())
    Details._op_getExternalInfo = IcePy.Operation('getExternalInfo', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ExternalInfo, False, 0), ())
    Details._op_setExternalInfo = IcePy.Operation('setExternalInfo', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExternalInfo, False, 0),), (), None, ())

    _M_omero.model.Details = Details
    del Details

    _M_omero.model.DetailsPrx = DetailsPrx
    del DetailsPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (C) 2014 Glencoe Software, Inc. All Rights Reserved.
# Use is subject to license terms supplied in LICENSE.txt
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

"""
Code-generated omero.model.ElectricPotential implementation,
based on omero.model.PermissionsI
"""


from builtins import str
from past.builtins import basestring
import Ice
import IceImport
IceImport.load("omero_model_ElectricPotential_ice")
_omero = Ice.openModule("omero")
_omero_model = Ice.openModule("omero.model")
__name__ = "omero.model"

from omero_model_UnitBase import UnitBase
from omero.model.enums import UnitsElectricPotential

from omero.conversions import Add  # nopep8
from omero.conversions import Int  # nopep8
from omero.conversions import Mul  # nopep8
from omero.conversions import Pow  # nopep8
from omero.conversions import Rat  # nopep8
from omero.conversions import Sym  # nopep8


class ElectricPotentialI(_omero_model.ElectricPotential, UnitBase):

    UNIT_VALUES = sorted(UnitsElectricPotential._enumerators.values())
    CONVERSIONS = dict()
    for val in UNIT_VALUES:
        CONVERSIONS[val] = dict()
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 16)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 19)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 17)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 36)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 20)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 33)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 6), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 42)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Int(1000), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ATTOVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 39)), Sym("attov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 16), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Rat(Int(1), Int(10)), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 20)), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 13), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 11)), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 4)), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 5)), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 8)), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Pow(10, 4), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Int(10), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 7), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 17)), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 10), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 14)), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Rat(Int(1), Int(100)), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 22), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 26)), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 19), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.CENTIVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 23)), Sym("centiv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 19), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Int(1000), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Int(100), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 17)), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 16), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 8)), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Rat(Int(1), Int(10)), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Rat(Int(1), Int(100)), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 5)), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Pow(10, 7), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Pow(10, 4), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 10), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 14)), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 13), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 11)), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Int(10), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 25), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 23)), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 22), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECAVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 20)), Sym("decav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 17), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Int(10), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Rat(Int(1), Int(100)), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 19)), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 14), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 10)), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 4)), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 7)), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Pow(10, 5), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Int(100), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 8), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 16)), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 11), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 13)), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Rat(Int(1), Int(10)), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 23), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 25)), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 20), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.DECIVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 22)), Sym("deciv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 36), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Pow(10, 20), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Pow(10, 17), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Pow(10, 19), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 33), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Pow(10, 9), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Pow(10, 16), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Pow(10, 15), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Pow(10, 12), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Pow(10, 24), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Pow(10, 21), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 27), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Int(1000), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 30), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Pow(10, 6), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Pow(10, 18), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 42), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 39), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.EXAVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("exav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Int(1000), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 13)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 16)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 14)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 33)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 17)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 9), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 39)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 6), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.FEMTOVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 36)), Sym("femtov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 27), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Pow(10, 11), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Pow(10, 8), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Pow(10, 10), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 24), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Pow(10, 7), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Pow(10, 6), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Int(1000), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Pow(10, 15), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Pow(10, 12), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 18), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 21), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Pow(10, 9), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 33), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 30), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.GIGAVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("gigav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 20), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Pow(10, 4), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Int(10), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Int(1000), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 16)), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 17), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 7)), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Rat(Int(1), Int(10)), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 4)), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Pow(10, 8), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Pow(10, 5), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 11), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 13)), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 14), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 10)), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Int(100), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 26), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 22)), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 23), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.HECTOVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 19)), Sym("hectov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 21), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Pow(10, 5), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Int(100), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Pow(10, 4), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 18), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Int(10), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Pow(10, 9), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Pow(10, 6), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 12), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 15), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Int(1000), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 27), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 24), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.KILOVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("kilov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 24), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Pow(10, 8), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Pow(10, 5), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Pow(10, 7), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 21), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Pow(10, 4), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Int(1000), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Pow(10, 12), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Pow(10, 9), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 15), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 18), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Pow(10, 6), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 30), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 27), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MEGAVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("megav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 12), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 4)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 7)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 5)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 9), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 8)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Int(1000), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 6), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 18), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 15), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MICROVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("microv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 15), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Rat(Int(1), Int(10)), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 4)), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Rat(Int(1), Int(100)), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 12), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 5)), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Int(1000), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 6), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 9), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 21), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 18), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.MILLIVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("milliv"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 9), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 7)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 10)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 8)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 6), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 11)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Int(1000), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 15), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 33)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 12), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.NANOVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("nanov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 33), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Pow(10, 17), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Pow(10, 14), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Pow(10, 16), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 30), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Pow(10, 6), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Pow(10, 13), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Pow(10, 12), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Pow(10, 9), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Pow(10, 21), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Pow(10, 18), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 24), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 27), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Int(1000), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Pow(10, 15), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 39), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 36), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PETAVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("petav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 6), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 10)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 13)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 11)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Int(1000), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 14)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 12), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 36)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 9), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.PICOVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 33)), Sym("picov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 30), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Pow(10, 14), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Pow(10, 11), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Pow(10, 13), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 27), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Int(1000), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Pow(10, 10), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Pow(10, 9), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Pow(10, 6), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Pow(10, 18), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Pow(10, 15), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 21), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 24), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Pow(10, 12), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 36), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 33), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.TERAVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("terav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 18), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Int(100), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Rat(Int(1), Int(10)), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Int(10), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 15), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Rat(Int(1), Int(100)), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Pow(10, 6), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Int(1000), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 9), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 12), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 24), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 21), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.VOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("v"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 22)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 25)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 23)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 42)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 33)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 26)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 39)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 36)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 48)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOCTOVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 45)), Sym("yoctov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 42), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Pow(10, 26), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Pow(10, 23), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Pow(10, 25), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Pow(10, 6), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 39), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Pow(10, 15), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Pow(10, 22), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Pow(10, 21), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Pow(10, 18), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Pow(10, 30), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Pow(10, 27), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 33), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Pow(10, 9), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 36), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Pow(10, 12), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Pow(10, 24), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 48), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 45), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.YOTTAVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Int(1000), Sym("yottav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 19)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 22)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 20)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 39)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 23)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 36)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 33)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Int(1000), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 45)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZEPTOVOLT][UnitsElectricPotential.ZETTAVOLT] = \
        Mul(Rat(Int(1), Pow(10, 42)), Sym("zeptov"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.ATTOVOLT] = \
        Mul(Pow(10, 39), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.CENTIVOLT] = \
        Mul(Pow(10, 23), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.DECAVOLT] = \
        Mul(Pow(10, 20), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.DECIVOLT] = \
        Mul(Pow(10, 22), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.EXAVOLT] = \
        Mul(Int(1000), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.FEMTOVOLT] = \
        Mul(Pow(10, 36), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.GIGAVOLT] = \
        Mul(Pow(10, 12), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.HECTOVOLT] = \
        Mul(Pow(10, 19), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.KILOVOLT] = \
        Mul(Pow(10, 18), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.MEGAVOLT] = \
        Mul(Pow(10, 15), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.MICROVOLT] = \
        Mul(Pow(10, 27), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.MILLIVOLT] = \
        Mul(Pow(10, 24), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.NANOVOLT] = \
        Mul(Pow(10, 30), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.PETAVOLT] = \
        Mul(Pow(10, 6), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.PICOVOLT] = \
        Mul(Pow(10, 33), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.TERAVOLT] = \
        Mul(Pow(10, 9), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.VOLT] = \
        Mul(Pow(10, 21), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.YOCTOVOLT] = \
        Mul(Pow(10, 45), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.YOTTAVOLT] = \
        Mul(Rat(Int(1), Int(1000)), Sym("zettav"))  # nopep8
    CONVERSIONS[UnitsElectricPotential.ZETTAVOLT][UnitsElectricPotential.ZEPTOVOLT] = \
        Mul(Pow(10, 42), Sym("zettav"))  # nopep8
    del val

    SYMBOLS = dict()
    SYMBOLS["ATTOVOLT"] = "aV"
    SYMBOLS["CENTIVOLT"] = "cV"
    SYMBOLS["DECAVOLT"] = "daV"
    SYMBOLS["DECIVOLT"] = "dV"
    SYMBOLS["EXAVOLT"] = "EV"
    SYMBOLS["FEMTOVOLT"] = "fV"
    SYMBOLS["GIGAVOLT"] = "GV"
    SYMBOLS["HECTOVOLT"] = "hV"
    SYMBOLS["KILOVOLT"] = "kV"
    SYMBOLS["MEGAVOLT"] = "MV"
    SYMBOLS["MICROVOLT"] = "µV"
    SYMBOLS["MILLIVOLT"] = "mV"
    SYMBOLS["NANOVOLT"] = "nV"
    SYMBOLS["PETAVOLT"] = "PV"
    SYMBOLS["PICOVOLT"] = "pV"
    SYMBOLS["TERAVOLT"] = "TV"
    SYMBOLS["VOLT"] = "V"
    SYMBOLS["YOCTOVOLT"] = "yV"
    SYMBOLS["YOTTAVOLT"] = "YV"
    SYMBOLS["ZEPTOVOLT"] = "zV"
    SYMBOLS["ZETTAVOLT"] = "ZV"

    def __init__(self, value=None, unit=None):
        _omero_model.ElectricPotential.__init__(self)

        if unit is None:
            target = None
        elif isinstance(unit, UnitsElectricPotential):
            target = unit
        elif isinstance(unit, basestring):
            target = getattr(UnitsElectricPotential, unit)
        else:
            raise Exception("Unknown unit: %s (%s)" % (
                unit, type(unit)
            ))

        if isinstance(value, _omero_model.ElectricPotentialI):
            # This is a copy-constructor call.

            source = value.getUnit()

            if target is None:
                raise Exception("Null target unit")
            if source is None:
                raise Exception("Null source unit")

            if target == source:
                self.setValue(value.getValue())
                self.setUnit(source)
            else:
                c = self.CONVERSIONS.get(source).get(target)
                if c is None:
                    t = (value.getValue(), source, target)
                    msg = "%s %s cannot be converted to %s" % t
                    raise Exception(msg)
                self.setValue(c(value.getValue()))
                self.setUnit(target)
        else:
            self.setValue(value)
            self.setUnit(target)

    def getUnit(self, current=None):
        return self._unit

    def getValue(self, current=None):
        return self._value

    def getSymbol(self, current=None):
        return self.SYMBOLS.get(str(self.getUnit()))

    @staticmethod
    def lookupSymbol(unit):
        return ElectricPotentialI.SYMBOLS.get(str(unit))

    def setUnit(self, unit, current=None):
        self._unit = unit

    def setValue(self, value, current=None):
        self._value = value

    def __str__(self):
        return self._base_string(self.getValue(), self.getUnit())

_omero_model.ElectricPotentialI = ElectricPotentialI
